/*--------------------------------------------------------------------*\
  File:      FontMenuItem.cpp
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1997, 1998, Matt Bogosian. All rights reserved.
  Description: Source file containing the member functions for the
      FontMenuItem class.
  ID:        $Id: FontMenuItem.cpp,v 1.16 1998/07/20 05:16:46 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include "FontMenuItem.h"
#include "FontMenu.h"
#include <string.h>


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-= Function Definitions =-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

//====================================================================
FontMenuItem::FontMenuItem(const font_family &a_family, const font_style &a_style, const bool a_use_font) :
//====================================================================
	Inherited("", NULL),
	m_use_font(a_use_font)
{
	SetLabel(a_style);
	Init(a_family, a_style);
}

//====================================================================
FontMenuItem::FontMenuItem(BMenu *a_menu, const font_family &a_family, const font_style &a_style, const bool a_use_font) :
//====================================================================
	Inherited(a_menu, NULL),
	m_use_font(a_use_font)
{
	SetLabel(a_family);
	Init(a_family, a_style);
}

//====================================================================
FontMenuItem::~FontMenuItem(void)
//====================================================================
{
	;
}

//====================================================================
void FontMenuItem::DrawContent(void)
//====================================================================
{
	if (!m_use_font)
	{
		// Call the original
		Inherited::DrawContent();
		return;
	}
	
	// Get the current font
	BFont orig_font, new_font;
	Menu()->GetFont(&orig_font);
	new_font = orig_font;
	
	// Set the new font
	new_font.SetFamilyAndStyle(m_family, m_style);
	Menu()->SetFont(&new_font, B_FONT_FAMILY_AND_STYLE);
	
	// Call the original
	Inherited::DrawContent();
	
	// Restore the original font
	Menu()->SetFont(&orig_font, B_FONT_FAMILY_AND_STYLE);
}

//====================================================================
void FontMenuItem::FamilyAndStyle(font_family &a_family, font_style &a_style) const
//====================================================================
{
	strcpy(a_family, m_family);
	strcpy(a_style, m_style);
}

//====================================================================
void FontMenuItem::GetContentSize(float *a_width, float *a_height)
//====================================================================
{
	if (!m_use_font)
	{
		// Call the original
		Inherited::GetContentSize(a_width, a_height);
		return;
	}
	
	// Get the current font
	BFont orig_font, new_font;
	Menu()->GetFont(&orig_font);
	new_font = orig_font;
	
	// Set the new font
	new_font.SetFamilyAndStyle(m_family, m_style);
	Menu()->SetFont(&new_font, B_FONT_FAMILY_AND_STYLE);
	
	// Call the original
	Inherited::GetContentSize(a_width, a_height);
	
	// Restore the original font
	Menu()->SetFont(&orig_font, B_FONT_FAMILY_AND_STYLE);
}

//====================================================================
void FontMenuItem::Init(const font_family &a_family, const font_style &a_style)
//====================================================================
{
	// Store the family and style
	strcpy(m_family, a_family);
	strcpy(m_style, a_style);
	
	// Set the message
	BMessage *msg;
	
	if ((msg = new BMessage(FontMenu::mk_msg_type)) == NULL)
	{
		return;
	}
	
	msg->AddString(FontMenu::mk_msg_fam, a_family);
	msg->AddString(FontMenu::mk_msg_stl, a_style);
	SetMessage(msg);
}
