/*--------------------------------------------------------------------*\
  File:      Main.cpp
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1997, 1998, Matt Bogosian. All rights reserved.
  Description: Source file containing the member functions for the
      Main class.
  ID:        $Id: Main.cpp,v 1.57 1998/07/20 05:06:41 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include "Main.h"
#include "Application.h"
#include <string.h>


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-= Function Definitions =-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

//====================================================================
int main(int a_argc, char *a_argv[])
//====================================================================
{
	Main *main;
	
	if ((main = new Main(a_argc, const_cast<const char **>(a_argv))) == NULL
		|| !main->Start())
	{
		Main::ErrExit(true, Main::mk_exit_code_err, "couldn't run\n");
	}
	
	delete main;
	
	return 0;
}

//====================================================================
Main::Main(int &a_argc, const char ** const a_argv) :
//====================================================================
	Inherited(a_argc, a_argv)
{
	;
}

//====================================================================
Main::~Main(void)
//====================================================================
{
	;
}

//====================================================================
void Main::Run(int &a_argc, const char ** const a_argv)
//====================================================================
{
	// Parse the command line options
	int err(0);
	
	if ((err = ParseOpts(a_argc, a_argv)) != mk_exit_code_no_err)
	{
		Exit(err);
	};
	
	// Do whatever
	if (a_argc != 1)
	{
		Usage();
		Exit(mk_exit_code_bad_args);
	}
	
	Application *app(new Application());
	
	if (app != NULL)
	{
		app->Run();
		delete app;
	}
	else
	{
		ExitNoMem();
	}
}

//====================================================================
void Main::Usage(void) const
//====================================================================
{
	Out(false, "Usage: %s [ OPTION ] ...\n", ProcName());
}

//====================================================================
void Main::Version(void) const
//====================================================================
{
	Out(false, "%s, version 1.0.3\n", ProcName());
}
