/*--------------------------------------------------------------------*\
  File:      Main.h
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1998, Matt Bogosian. All rights reserved.
  Description: Header file describing the Main class.
  ID:        $Id: Main.h,v 1.34 1998/07/20 05:06:41 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#define USE_LTTR_OPTS
#if defined USE_LTTR_OPTS
#include "PMainLttr.h"
#elif defined USE_WORD_OPTS
#include "PMainWord.h"
#else
#include "PMain.h"
#endif


#ifndef MAIN_H
#define MAIN_H


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-= Structs, Classes =-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

/*--------------------------------------------------------------------*\
  Class name:       Main
  Inherits from:    public PMainLttr/PMainWord/PMain
  New data members: none
  Description: Class to implement a main class.
\*--------------------------------------------------------------------*/

#if defined USE_LTTR_OPTS
class Main : public PMainLttr
#elif defined USE_WORD_OPTS
class Main : public PMainWord
#else
class Main : public PMain
#endif
{
	public:
	
		// Public member functions
		
/*--------------------------------------------------------------------*\
  Function name: Main
  Member of:     public Main
  Defined in:    Main.cpp
  Arguments:     int &a_argc - the number of command line arguments.
                 const char ** const a_argv - the command line
                     arguments.
  Returns:       n/a
  Throws:        none
  Description: Class constructor.
\*--------------------------------------------------------------------*/
		
		Main(int &a_argc, const char ** const a_argv);
		
/*--------------------------------------------------------------------*\
  Function name: virtual ~Main
  Member of:     public Main
  Defined in:    Main.cpp
  Arguments:     none
  Returns:       n/a
  Throws:        none
  Description: Class destructor.
\*--------------------------------------------------------------------*/
		
		virtual ~Main(void);
	
	protected:
	
		// Protected member functions
		
/*--------------------------------------------------------------------*\
  Function name: virtual Run
  Member of:     protected Main
  Defined in:    Main.cpp
  Arguments:     int &a_argc - the number of command line arguments.
                 const char ** const a_argv - the command line
                     arguments.
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void Run(int &a_argc, const char ** const a_argv);
		
/*--------------------------------------------------------------------*\
  Function name: virtual Usage const
  Member of:     protected Main
  Defined in:    Main.cpp
  Arguments:     none
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void Usage(void) const;
		
/*--------------------------------------------------------------------*\
  Function name: virtual Version const
  Member of:     protected Main
  Defined in:    Main.cpp
  Arguments:     none
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void Version(void) const;
	
	private:
	
#if defined USE_LTTR_OPTS
		typedef PMainLttr Inherited;
#elif defined USE_WORD_OPTS
		typedef PMainWord Inherited;
#else
		typedef PMain Inherited;
#endif
};


#endif    // MAIN_H
