/*--------------------------------------------------------------------*\
  File:      Window.cpp
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1997, 1998, Matt Bogosian. All rights reserved.
  Description: Source file containing the member functions for the
      Window class.
  ID:        $Id: Window.cpp,v 1.30 1998/07/20 05:16:46 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include "Window.h"
#include "FontMenu.h"
#include "PMain.h"
#include "View.h"
#include <Application.h>
#include <MenuBar.h>
#include <MenuItem.h>


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-= Function Definitions =-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

//====================================================================
Window::Window(BRect a_frame, const char * const a_name, status_t * const a_err) :
//====================================================================
	Inherited(a_frame, a_name, B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE),
	m_status(B_NO_ERROR)
{
	// Set up the menu item
	BMessage *msg;
	BMenuItem *menu_item;
	
	// Check for an allocation error
	if ((msg = new BMessage(B_QUIT_REQUESTED)) == NULL
		|| (menu_item = new BMenuItem("Quit", msg, 'Q')) == NULL)
	{
		delete msg;
		delete menu_item;
		m_status = B_NO_MEMORY;
		
		// Give the error back to the caller
		if (a_err != NULL)
		{
			*a_err = Status();
		}
		
		return;
	}
	
	// Set up the File menu and the menu bar
	a_frame.OffsetTo(B_ORIGIN);
	BMenu *menu;
	
	// Check for an allocation error
	if ((menu = new BMenu("File")) == NULL
		|| (m_menu_bar = new BMenuBar(a_frame, "Menu Bar")) == NULL)
	{
		delete msg;
		delete menu_item;
		delete menu;
		delete m_menu_bar;
		m_status = B_NO_MEMORY;
		
		// Give the error back to the caller
		if (a_err != NULL)
		{
			*a_err = Status();
		}
		
		return;
	}
	
	// Add it all to the window
	menu->AddItem(menu_item);
	m_menu_bar->AddItem(menu);
	AddChild(m_menu_bar);
	
#ifdef USE_FONT_MENU
	// We can add it to the window and then dick with it, or we
	// can do it the other way around
	if ((m_font_menu = new FontMenu()) == NULL)
	{
		m_status = B_NO_MEMORY;
		
		// Give the error back to the caller
		if (a_err != NULL)
		{
			*a_err = Status();
		}
		
		return;
	}
	
	m_menu_bar->AddItem(m_font_menu);
	
	// We can set the size explicitly if we want, so long as we do
	// it before it's initialized if we want the submenus to also
	// be that size
	BFont orig_font, new_font;
	m_font_menu->GetFont(&orig_font);
	new_font = orig_font;
	new_font.SetSize(new_font.Size() * 2);
	m_font_menu->SetFont(&new_font, B_FONT_SIZE);
	
	// Ready to rock and roll
	PMain::Verbose(false, "MyWindow::MyWindow(): initializing FontMenu...\n");
	m_font_menu->Initialize();
	
	// Now if we change the size after it has been initialized,
	// the submenus' size be unchanged
	m_font_menu->SetFont(&orig_font, B_FONT_SIZE);
#endif    // USE_FONT_MENU
	
	// Resize the window
	float menu_bar_height(m_menu_bar->Bounds().Height() + 1.0);
	ResizeBy(0, menu_bar_height);
	a_frame.OffsetBy(0, menu_bar_height);
	
	// Check for an allocation error
	if ((m_main_view = new View(a_frame, "View", &m_status)) == NULL)
	{
		m_status = B_NO_MEMORY;
		
		// Give the error back to the caller
		if (a_err != NULL)
		{
			*a_err = Status();
		}
		
		return;
	}
	
	// Check for an instantiation error
	if (m_status != B_NO_ERROR)
	{
		delete m_main_view;
		
		// Give the error back to the caller
		if (a_err != NULL)
		{
			*a_err = Status();
		}
		
		return;
	}
	
	AddChild(m_main_view);
	
	// Give the error back to the caller
	if (a_err != NULL)
	{
		*a_err = Status();
	}
}

//====================================================================
Window::~Window(void)
//====================================================================
{
	;
}

//====================================================================
void Window::MessageReceived(BMessage * const a_msg)
//====================================================================
{
#ifdef USE_FONT_MENU
	const char *family, *style;
	
	if (a_msg->what == FontMenu::mk_msg_type)
	{
		family = a_msg->FindString(FontMenu::mk_msg_fam);
		style = a_msg->FindString(FontMenu::mk_msg_stl);
		PMain::Verbose(false, "MyWindow::MessageReceived(): \"%s\", \"%s\"\n", family, style);
		m_font_menu->SetFamilyAndStyle(family, style);
		
		if (family != NULL && style != NULL)
		{
			BFont font;
			m_main_view->GetFont(&font);
			font.SetFamilyAndStyle(family, style);
			m_main_view->SetFont(&font, B_FONT_FAMILY_AND_STYLE);
		}
		
		m_main_view->Invalidate();
	}	
	else
#endif    // USE_FONT_MENU
	{
		Inherited::MessageReceived(a_msg);
	}
}

//====================================================================
bool Window::QuitRequested(void)
//====================================================================
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	
	return true;
}
