/*--------------------------------------------------------------------*\
  File:      Window.h
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1997, 1998, Matt Bogosian. All rights reserved.
  Description: Header file describing the Window class.
  ID:        $Id: Window.h,v 1.32 1998/07/20 05:16:46 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include <Window.h>


#ifndef WINDOW_H
#define WINDOW_H


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-= Definitions, Enums, Typedefs, Consts =-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#define USE_FONT_MENU


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-= Structs, Classes =-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

class BMenuBar;
class View;

#ifdef USE_FONT_MENU
class FontMenu;
#endif    // USE_FONT_MENU

/*--------------------------------------------------------------------*\
  Class name:       Window
  Inherits from:    public BWindow
  New data members: private status_t m_status - the status of the
                        object.
                    private BMenuBar *m_menu_bar - the window's main
                        menu bar.
                    private View *m_main_view - the window's main
                        view.
                    private FontMenu *m_font_menu - the main menu
                        bar's font menu.
  Description: Class to implement a window to quit the application
      when closed, and in which is displayed a menu bar and a view.
\*--------------------------------------------------------------------*/

class Window : public BWindow
{
	public:
	
		// Public static const data members
		
		// Public static data members
		
		// Public data members
		
		// Public static member functions
		
		// Public member functions
		
/*--------------------------------------------------------------------*\
  Function name: Window
  Member of:     public Window
  Defined in:    Window.cpp
  Arguments:     BRect a_frame - the frame of the window.
                 const char * const a_name - the name of the window.
                 status_t * const a_err - a placeholder for the error
                     encountered during construction (see below).
                     Default: NULL.
  Throws:        none
  Description: Class constructor. You must check the value of a_err or
      the return value of Status() after invoking the constructor to
      see if the object is usable. See the Status() function (below)
      for possible error values.
\*--------------------------------------------------------------------*/
		
		Window(BRect a_frame, const char * const a_name, status_t * const a_err = NULL);
		
/*--------------------------------------------------------------------*\
  Function name: virtual ~Window
  Member of:     public Window
  Defined in:    Window.cpp
  Arguments:     none
  Throws:        none
  Description: Class destructor.
\*--------------------------------------------------------------------*/
		
		virtual ~Window(void);
		
/*--------------------------------------------------------------------*\
  Function name: virtual MessageReceived
  Member of:     public Window
  Defined in:    Window.cpp
  Arguments:     BMessage * const a_msg - the message received.
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void MessageReceived(BMessage * const a_msg);
		
/*--------------------------------------------------------------------*\
  Function name: virtual QuitRequested
  Member of:     public Window
  Defined in:    Window.cpp
  Arguments:     none
  Returns:       bool - true if the window will quit, false otherwise.
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual bool QuitRequested(void);
		
/*--------------------------------------------------------------------*\
  Function name: inline Status const
  Member of:     public Window
  Arguments:     none
  Returns:       status_t - B_NO_ERROR if the object is valid, another
                     error code if not (see below).
  Throws:        none
  Description: Function to check if the object is valid. This function
      must be called after creating the object to insure that its
      instantiation was successful. Possible return values are as
      follows:
      
      B_NO_ERROR - the object was created successfully.
      B_NO_MEMORY - on construction, there was not enough memory
          available to create the object.
\*--------------------------------------------------------------------*/
		
		inline status_t Status(void) const
		{
			return m_status;
		}
	
	private:
	
		typedef BWindow Inherited;
		
		// Private data members
		status_t m_status;
		BMenuBar *m_menu_bar;
		View *m_main_view;
		
#ifdef USE_FONT_MENU
		FontMenu *m_font_menu;
#endif    // USE_FONT_MENU
};


#endif    // WINDOW_H
